@@ -1,13 +1,36 @@
 package Syntax::Keyword::Junction::All;
-BEGIN {
-  $Syntax::Keyword::Junction::All::VERSION = '0.002001';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.003000'; # VERSION
+
 use base 'Syntax::Keyword::Junction::Base';
 
+BEGIN {
+  if ($] >= 5.010001) {
+    eval q<
+sub match {
+    my ( $self, $other, $is_rhs ) = @_;
+
+    if ($is_rhs) {
+        for (@$self) {
+            return unless $other ~~ $_;
+        }
+
+        return 1;
+    }
+
+    for (@$self) {
+        return unless $_ ~~ $other;
+    }
+
+    return 1;
+}
+>
+  }
+}
+
 sub num_eq {
     return regex_eq(@_) if ref( $_[1] ) eq 'Regexp';
 
@@ -190,7 +213,7 @@ Syntax::Keyword::Junction::All
 
 =head1 VERSION
 
-version 0.002001
+version 0.003000
 
 =head1 AUTHORS
 
@@ -208,7 +231,7 @@ Carl Franks
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2012 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
